%global srcname starkbank-ecdsa
%global py3_name python3-%{srcname}

%global desc %{expand: \
We tried other Python libraries such as python-ecdsa, fast-ecdsa and other 
less famous ones, but we didn't find anything that suited our needs. 
The first one was pure Python, but it was too slow. The second one mixed 
Python and C and it was really fast, but we were unable to use it in our 
current infrastructure, which required pure Python code.

For this reason, we decided to create something simple, compatible with 
OpenSSL and fast using elegant math such as Jacobian Coordinates to speed up
the ECDSA. Starkbank-ECDSA is fully compatible with Python2 and Python3.
}

Name:		python-%{srcname}
Version:	2.0.3
Release:	1%{?dist}
Summary:	A lightweight and fast pure Python ECDSA library

License:	MIT
URL:		https://github.com/starkbank/ecdsa-python
Source0:	%{url}/archive/v%{version}/ecdsa-python-%{version}.tar.gz

BuildArch:	noarch

BuildRequires:	python3-devel
BuildRequires:	python3-pytest
BuildRequires:	pyproject-rpm-macros

%description
%{desc}

%package -n %{py3_name}
Summary:	%{summary}

%description -n %{py3_name}
%{summary}.

%prep
%autosetup -n ecdsa-python-%{version}

# exclude test files
sed -i 's/find_packages()/find_packages(exclude=["tests"])/g' setup.py

%generate_buildrequires
%pyproject_buildrequires -r

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files ellipticcurve

%check
cd tests
PYTHONPATH=%{buildroot}%{python3_sitelib} %{__python3} -m unittest discover -v

%files -n %{py3_name} -f %{pyproject_files}
%doc README.md CHANGELOG.md

%changelog
* Mon Jun 27 2022 Ali Erdinc Koroglu <aekoroglu@fedoraproject.org> - 2.0.3-1
- Initial package
